/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of TMRB_PPG demo for the TOSHIBA
 *          'TMPM365' Device Series 
 * @version V0.102
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  delay some time
  * @param  delay time
  * @retval None.
  */
void delay(uint32_t time)
{
    volatile uint32_t i;
    for (i = 0U; i < time; i++) {
        /* Do nothing */
    }
}

/**
  * @brief  The main function of TMRB_PPG demo
  * @param  None
  * @retval None
  */
int main(void)
{
    uint8_t Rate = 0U;
    uint32_t LeadingTiming[5] = { 0xA8CU, 0x8CAU, 0x5DCU, 0x2EEU, 0x12CU };      /* leadingtiming: 10%, 25%, 50%, 75%, 90% */
    uint8_t keyvalue;

    TMRB_InitTypeDef m_tmrb;
    TMRB_FFOutputTypeDef PPGFFInital;

    GPIO_SetInput(KEYPORT, GPIO_BIT_1); /* set KEY port to input */

    /* Set PH2 as TB4OUT for PPG output */
    GPIO_SetOutput(GPIO_PH, GPIO_BIT_2);
    GPIO_EnableFuncReg(GPIO_PH, GPIO_FUNC_REG_3, GPIO_BIT_2);

    m_tmrb.Mode = TMRB_INTERVAL_TIMER;
    m_tmrb.ClkDiv = TMRB_CLK_DIV_8;
    m_tmrb.UpCntCtrl = TMRB_AUTO_CLEAR;
    m_tmrb.TrailingTiming = TMRB4TIME;   /* T = 500us */
    m_tmrb.LeadingTiming = LeadingTiming[Rate];
    PPGFFInital.FlipflopCtrl = TMRB_FLIPFLOP_CLEAR;
    PPGFFInital.FlipflopReverseTrg = TMRB_FLIPFLOP_MATCH_TRAILINGTIMING | TMRB_FLIPFLOP_MATCH_LEADINGTIMING;

    TMRB_Enable(TSB_TB4);
    TMRB_Init(TSB_TB4, &m_tmrb);
    TMRB_SetFlipFlop(TSB_TB4, &PPGFFInital);
    TMRB_SetDoubleBuf(TSB_TB4, ENABLE); /* enable double buffer */
    TMRB_SetRunState(TSB_TB4, TMRB_RUN);

    while (1) {
        /* Press SW1 and release to change the leadingtiming */
        do {
            keyvalue = GPIO_ReadDataBit(KEYPORT, GPIO_BIT_1);
        } while (GPIO_BIT_VALUE_0 == keyvalue);

        delay(0xFFFU);          /* noise cancel */

        do {
            keyvalue = GPIO_ReadDataBit(KEYPORT, GPIO_BIT_1);
        } while (GPIO_BIT_VALUE_1 == keyvalue);

        delay(0xFFFU);          /* noise cancel */

        Rate++;
        if (Rate >= LEADINGTIMINGMAX) {  /* change leadingtiming rate */
            Rate = LEADINGTIMINGINIT;
        } else {
            /* Do nothing */
        }

        TMRB_ChangeLeadingTiming(TSB_TB4, LeadingTiming[Rate]);   /* switch is High again */
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
