/**
 *******************************************************************************
 * @file    usbd_trans.h
 * @brief   USB EPx Transfer Header for TOSHIBA 'TMPM366' Device Series
 * @version V0.201
 * @date    2014/05/20
 *
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 *
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#ifndef _USBD_TRANS_H_
#define _USBD_TRANS_H_

#include "usbd_hw.h"
#include "usbd_device_request.h"

/* typedef for callback function */
typedef void    (*EpCallbackFunc)(USBD_EPx);

/* Endpoint Transfer Information */
typedef struct {
    uint16_t        usEpNum;        /* Endpoint Number */
    uint16_t        usEpStat;       /* Endpoint Status */
#define EPSTAT_IDLE             0U      /* IDLE */
#define EPSTAT_BUSY             1U      /* BUSY (blocking) */
#define EPSTAT_COMPLETE         2U      /* COMPLETE (blocking) */
#define EPSTAT_ERROR            3U      /* ERROR (blocking) */
#define EPSTAT_ABORT            4U      /* ABORT (blocking) */
    uint32_t        ulReqSize;      /* Endpoint Request Size */
    uint32_t        ulTransSize;    /* Endpoint Transfered Size */
    uint8_t*        pucBuf;         /* Endpoint Buffer Pointer */
    uint8_t*        pucCurBuf;      /* Endpoint Current Buffer Pointer */
    void*           pvInfo;         /* Endpoint Additional Information */
    EpCallbackFunc  pfnCallback;    /* Endpoint Callback Function */
} EpTransInfo_t;

/* prototypes */
extern bool usbd_Epx_Recv(USBD_EPx, uint32_t, uint8_t*, void*, EpCallbackFunc);
extern bool usbd_Epx_Send(USBD_EPx, uint32_t, uint8_t*, void*, EpCallbackFunc);
extern bool usbd_Epx_Abort(USBD_EPx);
extern void usbd_Epx_Read_Fifo(USBD_EPx);
extern void usbd_Epx_Write_Fifo(USBD_EPx);

#endif  /* _USBD_TRANS_H_ */
